-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftRaidIcon")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Raid Icon"] = true,
	["Raid icon placement options"] = true,
	["Enable"] = true,
	["Enable raid icon display on the nameplate"] = true,
	["Size"] = true,
	["Size in pixels of the raid icon"] = true,
	["X Offset"] = true,
	["X offset of the raid icon"] = true,
	["Y Offset"] = true,
	["Y offset of the raid icon"] = true,
	["Anchor"] = true, 
	["Sets the anchor for the raid icon"] = true,
	["Anchor To"] = true, 
	["Sets the relative point on the health bar to anchor the raid icon"] = true,
	["Alpha"] = true,
	["Sets the raid icon alpha"] = true,
} end)

-----------------------------------------------------------------------------

local AloftRaidIcon = Aloft:NewModule("RaidIcon", "AceEvent-2.0")
AloftRaidIcon.db = Aloft:AcquireDBNamespace("raidIcon")
Aloft:RegisterDefaults("raidIcon", "profile", {
	enable			= true,
	alpha			= 0.75,
	point			= "CENTER",
	relativeToPoint	= "CENTER",
	offsetX			= 0,
	offsetY			= 0,
	size			= 32
})

Aloft.Options.args.raidIcon =
{
	type = 'group',
	name = L["Raid Icon"],
	desc = L["Raid icon placement options"],
	disabled = function() return not Aloft:IsActive() end,
	args =
	{
		enable = 
		{
			type = 'toggle',
			name = L["Enable"],
			desc = L["Enable raid icon display on the nameplate"],
			get = function() return AloftRaidIcon.db.profile.enable end,
			set = function(v) AloftRaidIcon.db.profile.enable = v AloftRaidIcon:UpdateAll() end,
			order = 1
		},
		anchor = {
			type = "text", 
			name = L["Anchor"], 
			desc = L["Sets the anchor for the raid icon"],
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.point end,
			set = function(v) AloftRaidIcon.db.profile.point = v AloftRaidIcon:UpdateAll() end,
			validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
		},
		anchorto = {
			type = "text", 
			name = L["Anchor To"], 
			desc = L["Sets the relative point on the health bar to anchor the raid icon"],
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.relativeToPoint end,
			set = function(v) AloftRaidIcon.db.profile.relativeToPoint = v AloftRaidIcon:UpdateAll() end,
			validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
		},
		size =
		{
			type = 'range',
			name = L["Size"],
			desc = L["Size in pixels of the raid icon"],
			min = 4,
			max = 64,
			step = 1,
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.size end,
			set = function(v) AloftRaidIcon.db.profile.size = v AloftRaidIcon:UpdateAll() end
		},
		offsetX =
		{
			type = 'range',
			name = L["X Offset"],
			desc = L["X offset of the raid icon"],
			min = -32,
			max = 32,
			step = 1,
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.offsetX end,
			set = function(v) AloftRaidIcon.db.profile.offsetX = v AloftRaidIcon:UpdateAll() end
		},
		offsetY =
		{
			type = 'range',
			name = L["Y Offset"],
			desc = L["Y offset of the raid icon"],
			min = -32,
			max = 32,
			step = 1,
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.offsetY end,
			set = function(v) AloftRaidIcon.db.profile.offsetY = v AloftRaidIcon:UpdateAll() end
		},
		alpha =
		{
			type = 'range',
			name = L["Alpha"],
			desc = L["Sets the raid icon alpha"],
			min = 0,
			max = 1.0,
			step = 0.05,
			disabled = function() return not AloftRaidIcon.db.profile.enable end,
			get = function() return AloftRaidIcon.db.profile.alpha end,
			set = function(v) AloftRaidIcon.db.profile.alpha = v AloftRaidIcon:UpdateAll() end
		},
	},
}

-----------------------------------------------------------------------------

function AloftRaidIcon:UpdateAll()
	for frame in Aloft:IterateNameplates() do
		local raidIconFrame = select(8, frame:GetRegions())
		self:PlaceFrame(raidIconFrame, frame.aloftData.healthBar, self.db.profile)
	end
end

-----------------------------------------------------------------------------

function AloftRaidIcon:OnEnable()
	self:RegisterEvent("Aloft:SetupFrame", "SetupFrame")
	self:UpdateAll()
end

function AloftRaidIcon:OnDisable()
	self:UnregisterAllEvents()

	for frame in Aloft:IterateNameplates() do
		local raidIconFrame = select(8, frame:GetRegions())
		raidIconFrame:ClearAllPoints()
		raidIconFrame:SetPoint("RIGHT", frame, "LEFT")
		raidIconFrame:SetWidth(29)
		raidIconFrame:SetHeight(29)
		raidIconFrame:SetAlpha(1)
	end
end

function AloftRaidIcon:SetupFrame(frame)
	local raidIconFrame = select(8, frame:GetRegions())
	self:PlaceFrame(raidIconFrame, frame.aloftData.healthBar, self.db.profile)
end

-----------------------------------------------------------------------------
